seq/for_each.hpp

The seq/for_each.hpp header defines macros to repeat a macro for each element in a seq.

#### Usage

#include <boost/preprocessor/seq/for_each.hpp>

#### Contents

- BOOST_PP_SEQ_FOR_EACH
- BOOST_PP_SEQ_FOR_EACH_R

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)